==> payara-embedded-all-5.2020.4-sources.jar: org/glassfish/sse/api/ServerSentEventConnection.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.sse.api;

import javax.servlet.http.HttpServletRequest;
import java.io.Closeable;
import java.io.IOException;

/**
 * Represents a Server-Sent Event connection for sending push notifications
 *
 * @author Jitendra Kotamraju
 */
public abstract class ServerSentEventConnection implements Closeable {

    /**
     * Servlet request for Server-Sent Event connection
     *
     * @return servlet request
     */
    public abstract HttpServletRequest getRequest();

    /**
     * Event source's last event ID.
     *
     * @return null if there is no HTTP header in the request
     *         otherwise, last event ID
     */
    public String getLastEventID() {
        return getRequest().getHeader("Last-Event-ID");
    }

    /**
     * Sends the Server-Sent event to client
     *
     * @param eventData Server-Sent event data
     * @throws IOException when there is an error in sending
     * @throws IllegalStateException when called after calling close method
     * @see ServerSentEventData
     */
    public abstract void sendMessage(String eventData) throws IOException;

    /**
     * Sends the Server-Sent event to client
     * @param eventData Server-Sent event data
     * @throws IOException when there is an error in sending
     * @throws IllegalStateException when called after calling close method
     * @see ServerSentEventData
     */
    public abstract void sendMessage(ServerSentEventData eventData)
            throws IOException;

    /**
     * Closes the connection
     */
    public abstract void close();

}

==> payara-embedded-all-6.2023.2-sources.jar: org/glassfish/sse/api/ServerSentEventConnection.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.sse.api;

import jakarta.servlet.http.HttpServletRequest;
import java.io.Closeable;
import java.io.IOException;

/**
 * Represents a Server-Sent Event connection for sending push notifications
 *
 * @author Jitendra Kotamraju
 */
public abstract class ServerSentEventConnection implements Closeable {

    /**
     * Servlet request for Server-Sent Event connection
     *
     * @return servlet request
     */
    public abstract HttpServletRequest getRequest();

    /**
     * Event source's last event ID.
     *
     * @return null if there is no HTTP header in the request
     *         otherwise, last event ID
     */
    public String getLastEventID() {
        return getRequest().getHeader("Last-Event-ID");
    }

    /**
     * Sends the Server-Sent event to client
     *
     * @param eventData Server-Sent event data
     * @throws IOException when there is an error in sending
     * @throws IllegalStateException when called after calling close method
     * @see ServerSentEventData
     */
    public abstract void sendMessage(String eventData) throws IOException;

    /**
     * Sends the Server-Sent event to client
     * @param eventData Server-Sent event data
     * @throws IOException when there is an error in sending
     * @throws IllegalStateException when called after calling close method
     * @see ServerSentEventData
     */
    public abstract void sendMessage(ServerSentEventData eventData)
            throws IOException;

    /**
     * Closes the connection
     */
    public abstract void close();

}
